# Security Policy

## Supported Versions

Always use the most recent version. There will be no support for older
versions.

## Reporting a Vulnerability

If you identify a vulnerability, please consider that this may affect other
people/projects as well. This in mind please email me (Yannic Labonte
<yannic.labonte@gmail.com>) first, so I can react and maybe fix the issue,
before publishing it to the public (e.g. in a github issue).
